function [casinoData,status] = processCasinoOutput(filename)
% PROCESSCASINOOUTPUT Read CASINO output file 
%   [casinoData,status] = processCasinoOutput(filename) returns the MATLAB
%   structured data named casinoData and the status of the process. If
%   error occurs in processing the Casino file, the function will return
%   empty casinoData struct and with negative value for the status

fid = fopen(filename);
if fid < 0
    status = -2;
    casinoData='';
    return;
end

% Read the header of the file and extract the x, y, and z range. If other
% type of CASINO file is being read, the function will return to the caller
% function with empty struct data and -1 status
planeLineNumber = 0;
headerDone = 0;
axesInfo = {'X','Y','Z'};
lineNum = 0;
MAXHEADERLINE = 20;          %Maximum lines of header
while headerDone == 0
    lineNum = lineNum + 1;
    lineval = fgetl(fid);
    if strfind(lineval,'divisions')
        for i=1:3
            strval = strsplit(lineval,' ');
            inc = strval{2};
            layerinc = str2num(inc(2:end));
            numDivision=str2num(strval{5});
            casinoData.(axesInfo{i}).inc = layerinc;
            casinoData.(axesInfo{i}).numDivision = numDivision;
            if i<3
                lineval = fgetl(fid);
                lineNum = lineNum + 1;
            end
        end
    elseif strfind(lineval,'Range')
        for i=1:3
            strval = strsplit(lineval,':');
            st = strval{2};
            st = strsplit(st,' ');
            ed = strval{end};
            layerRange=[str2num(st{1}) str2num(ed(1:end-2))];
            casinoData.(axesInfo{i}).range=layerRange;
            lineval = fgetl(fid);
            lineNum = lineNum + 1;
        end
        headerDone=1;
    elseif lineNum > MAXHEADERLINE
        status = -1;
        casinoData='';
        return;
    end
end

% Once header has been read, start loading the data
while ~feof(fid)
    lineval = fgetl(fid);
    % Store the plane info
    if strfind(lineval,'plane') 
        if strfind(lineval, 'planes')
            lineval = fgetl(fid);
        end
        planeType = lineval(1:strfind(lineval,'plane')-2);
        positionType = lineval(strfind(lineval,'Position')-2);
        colIndex = strfind(lineval,':');
        pos = str2num(lineval(colIndex+1:end-2));
        planeVal = str2num(lineval(9:strfind(lineval,'Position')-3));
        planeName = [planeType int2str(planeVal)];
        casinoData.data.(planeName).([positionType 'Pos']) = pos;
        
        if planeLineNumber > 0
            try
            data = dlmread([pwd '/temp.dat']);
            catch
                lineval;
            end
            casinoData.data.(oldxzPlane).map = data(2:end,2:end);
            casinoData.data.(oldxzPlane).Xaxis = data(1,:);
            casinoData.data.(oldxzPlane).(oldaxis) = data(2:end,1);
            planeLineNumber = 0;
            fclose(tempFid);
            delete temp.dat;
        end
        tempFid = fopen([pwd '/temp.dat'],'w');
        oldxzPlane = planeName;
        oldaxis = [positionType 'axis'];
    else
        newLine = strrep(lineval,'nm','');
        fprintf(tempFid,[newLine '\n']);
        planeLineNumber = planeLineNumber + 1;
    end
end

data = dlmread([pwd '/temp.dat']);
casinoData.data.(oldxzPlane).map = data(2:end,2:end);
casinoData.data.(oldxzPlane).Xaxis = data(1,:);
casinoData.data.(oldxzPlane).(oldaxis) = data(2:end,1);
planeLineNumber = 0;
fclose all;
delete temp.dat;
status = 1;

end